
Examples
================================
.. toctree::
    :glob:
    :maxdepth: 2

    plot/*
    fit/*
    interpolate/*
    latex/*
    parallel/*
    uncertainties/*
    pandas/*
    animations/*
    parallel/*
